from setuptools import find_packages, setup
setup(
    name='moje_pliki',
    version='0.1.0',
    author='Me',
    author_email='damiandubaj@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    description='my library'
)